API reference
=============

The reference manual provides detailed descriptions of the classes and
functions exposed by MicroPie.  These documents are factual and
succinct.  For tutorials and recipes, see the
:doc:`../tutorial/index` and :doc:`../howto/index` sections.

.. toctree::
   :maxdepth: 1
   :caption: Reference

   app
   request
   websocket
   middleware
   session
   exceptions
